%define name	gtkpod
%define version 2.0.0
%define git 0
%if %git
%define release %mkrel -c %git 1
%else
%define release %mkrel 5
%endif

%define major     1
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name: 	 	%{name}
Summary: 	GTK interface to iPod
Version: 	%{version}
Release: 	%{release}
%if %git
Source0:       %{name}-%{git}.tar.xz
%else
Source0:	http://prdownloads.sourceforge.net/gtkpod/%{name}-%version.tar.gz
%endif
Patch1: gtkpod-cover.patch
Patch4: gtkpod-tomboy-notes-path.patch
Patch5: gtkpod-fix-quoting-in-sync-scripts.patch
Patch6: gtkpod-2.0.0-format-string-literal.patch
Patch7: gtkpod-2.0.0-dont-disable-deprecated-gtk-api.patch
URL:		http://gtkpod.sourceforge.net/
License:	GPLv2+
Group:		Communications
BuildRequires:	libid3tag-devel
BuildRequires:	libmp4v2-devel
BuildRequires:	libgpod-devel >= 0.7.0
BuildRequires:	libvorbis-devel
BuildRequires:	libflac-devel
BuildRequires:	glib2-devel >= 2.15
BuildRequires:	gtk2-devel libglade2.0-devel
BuildRequires:	libcurl-devel
BuildRequires:	flex
BuildRequires:  intltool
BuildRequires:  desktop-file-utils
BuildRequires:	anjuta-devel
BuildRequires:	libgdl-devel
BuildRequires:	webkitgtk-devel
BuildRequires:	gstreamer0.10-devel
Suggests: %mklibname mp4v2_ 1
Requires: %{libname} = %{version}-%{release}

%description
gtkpod is a platform independent GUI for Apple's iPod using GTK2. It allows
you to upload songs and playlists to your iPod. It supports ID3 tag editing,
multiple charsets for ID3 tags, detects duplicate songs, allows offline
modification of the database with later synchronisation, and more.

gtkpod allows you to
    * Read your existing iTunesDB (i.e. import the existing contents of
      your iPod).
    * Add mp3 files to the iPod. You can choose the charset the ID3 tags
      are encoded in from within gtkpod. The default is the charset
      currently used by your locale setting.
    * When adding songs, gtkpod detects duplicates (opt).
    * Remove songs from the iPod.
    * Create and modify playlists.
    * Modify ID3 tags -- changes are also updated in the original file (opt)
    * Write the updated iTunesDB and added songs to your iPod.
    * Work offline and synchronize your new playlists / songs with the iPod
      at a later time.

%package -n %{libname}
Summary: Library package for %{name}
Group:   Communications

%description -n %{libname}
Library package for %{name}.

%package -n %{develname}
Summary: Development files for %{name}
Group: Communications
Requires: %{libname} = %{version}-%{release}

%description -n %{develname}
Development files for %{name}, you need this package if you want to compile
applications against %{name}.

%prep
%if %git
%setup -q -n %name
./autogen.sh -V
%else
%setup -q -n %name-%version
%endif
%patch1 -p1 -b .cover
%patch4 -p0 -b .tomboy
%patch5 -p1 -b .fix-quoting
%patch6 -p1 -b .format-string
%patch7 -p1 -b .gtk-deprecated-api

# needed for patch7
autoconf

chmod 644 README ChangeLog COPYING AUTHORS

%build
%configure2_5x --disable-static
%make

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

%find_lang %{name}

%if %_lib != lib
perl -pi -e "s!%_prefix/lib!%_libdir!g" %buildroot%_datadir/%name/scripts/sync-evolution.sh
%endif

desktop-file-install --vendor="" \
  --add-mime-type="x-content/audio-player" \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications $RPM_BUILD_ROOT%{_datadir}/applications/*

# don't ship .la
find %{buildroot} -name '*.la' | xargs rm -f

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{name}.lang
%defattr(-,root,root)
%doc README AUTHORS ChangeLog
%{_bindir}/%{name}
%{_libdir}/%{name}/*.plugin
%{_libdir}/%{name}/*.so
%{_datadir}/%{name}
%{_datadir}/applications/gtkpod.desktop
%{_datadir}/icons/hicolor/*/apps/gtkpod.*
%{_mandir}/man1/gtkpod.1*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libgtkpod.so.%{major}*

%files -n %{develname}
%defattr(-,root,root)
%{_includedir}/gtkpod/
%{_libdir}/libgtkpod.so
%{_libdir}/pkgconfig/libgtkpod-1.0.pc


%changelog
* Sun May 15 2011 pterjan <pterjan> 2.0.0-5.mga1
+ Revision: 99001
- Rebuild for fixed find-requires

* Sat Apr 30 2011 misc <misc> 2.0.0-4.mga1
+ Revision: 94002
- increase Release to let people upgrade even from backport

* Wed Apr 20 2011 ahmad <ahmad> 2.0.0-1.mga1
+ Revision: 89311
- Update to 2.0.0
- Add lib package
- Drop patch3 (mountpoint), fixed upstream
- Rediff patch1 (cover.patch)
- Add patch to fix format string
- Add patch to fix building with deprecated GTK+ API
- Add BR: anjuta-devel, libgdl-devel, webkitgtk-devel, gstreamer0.10-devel
- Disable static building, and don't ship .la
- m4a plugin is disabled as it require faad2-devel BR, remember to enable it
  once we can build packages for two targets

* Sat Feb 26 2011 supp <supp> 1.0.0-1.mga1
+ Revision: 60098
- imported package gtkpod

